@@ -82,13 +82,21 @@ class PyodbcResource(object):
 
     def callproc(self, procname, *args):
         cursor = self._connection.cursor()
-        argsOut = cursor.callproc(procname, *args)
-        return argsOut, PyodbcCursorContext(cursor)
+        try:
+            argsOut = cursor.callproc(procname, *args)
+            return argsOut, PyodbcCursorContext(cursor)
+        except:
+            cursor.close()
+            raise
 
     def execute(self, query, *args):
         cursor = self._connection.cursor()
-        cursor.execute(query, *args)
-        return PyodbcCursorContext(cursor)
+        try:
+            cursor.execute(query, *args)
+            return PyodbcCursorContext(cursor)
+        except:
+            cursor.close()
+            raise
 
     def rollback(self):
         self._connection.rollback()
